/*
 * Copyright (c) 2022, NVIDIA CORPORATION.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU General Public License,
 * version 2, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _NVGUARD_SERVICEID_H
#define _NVGUARD_SERVICEID_H

#define NVGUARD_UNIQUESUBID_FIELDMASK (0x000001FFU)
#define NVGUARD_ECACCESS_FIELDMASK    (0x00000200U)
#define NVGUARD_ECACCESS_FIELDSHIFT   (9U)
#define NVGUARD_GROUPID_FIELDMASK     (0x000FFC00U)
#define NVGUARD_GROUPID_FIELDSHIFT    (10U)
#define NVGUARD_ERRTYPE_FIELDMASK     (0x00F00000U)
#define NVGUARD_ERRTYPE_FIELDSHIFT    (20U)
#define NVGUARD_LAYER_FIELDMASK       (0x0F000000U)
#define NVGUARD_LAYER_FIELDSHIFT      (24U)
#define NVGUARD_SWERRMASK             (0x00100000U)
#define NVGUARD_DIAGIDMASK            (0x00200000U)

#define NVGUARD_SERVICE_INVALID       (0x0U)


/* *************** SERVICE ID for L1SS*************** */
/*  IDs for SW Error Handler */
/** DESCRIPTION : L1SS internal error */
#define NVGUARD_SERVICE_L1SS_SWERR_INTERNAL_ERROR 0x01100400U
/** DESCRIPTION : L1SS client error */
#define NVGUARD_SERVICE_L1SS_SWERR_CLIENT_ERROR 0x01100401U
/** DESCRIPTION : L1SS configuration error */
#define NVGUARD_SERVICE_L1SS_SWERR_CONFIG_ERROR 0x01100402U
#define NVGUARD_SERVICE_L1SS_MAX_SWERR 3U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_L1SS_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_L1SS_HSMERR_SCE_FABRIC_FUNC_UE 0x010004b9U
#define NVGUARD_SERVICE_L1SS_MAX_HWERR 1U
/* *************** END SERVICE ID for L1SS*************** */

/* *************** SERVICE ID for SCE*************** */
/*  IDs for SW Error Handler */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_SCE_SWERR_L2SS_INTERNAL_ERROR 0x02100800U
#define NVGUARD_SERVICE_SCE_MAX_SWERR 1U
/* IDs for Diagnostics Test Services */
/** DESCRIPTION : SCE NOC built in test */
#define NVGUARD_SERVICE_SCE_DIAG_NOC_BIST 0x02200800U
/** DESCRIPTION : LIC Channel 4 and Channel 5 register monitoring */
#define NVGUARD_SERVICE_SCE_DIAG_SCELIC_MONITORERROR 0x02200801U
/** DESCRIPTION : HSM configuration register periodic monitoring */
#define NVGUARD_SERVICE_SCE_DIAG_HSMCONFIG_MONITOR 0x02200802U
#define NVGUARD_SERVICE_SCE_MAX_DIAG 3U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SCE_HSMERR_APE_UE 0x02000818U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SCE_HSMERR_BPMP_TKE_UE 0x0200081cU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SCE_HSMERR_HSM_TIMER_UE 0x02000823U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SCE_HSMERR_HSM_UE 0x02000a28U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SCE_HSMERR_SCE_TKE_UE 0x020008b8U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SCE_HSMERR_SCE_FABRIC_UE 0x020008baU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SCE_HSMERR_SCE_CLUSTER_UE 0x02000abbU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SCE_HSMERR_SCE_DMA_UE 0x020008beU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SCE_HSMERR_AON_CLUSTER_UE 0x02000ac7U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SCE_HSMERR_SCE_CLUSTER_CE 0x02000bdbU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SCE_HSMERR_SCE_DMA_CE 0x020009dcU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SCE_HSMERR_AON_CLUSTER_CE 0x02000be1U
#define NVGUARD_SERVICE_SCE_MAX_HWERR 12U
/* *************** END SERVICE ID for SCE*************** */

/* *************** SERVICE ID for DRIVEOSAPP*************** */
/*  IDs for SW Error Handler */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_DRIVEOSAPP_SWERR_DRAM_PAGE_ERR 0x0110103fU
#define NVGUARD_SERVICE_DRIVEOSAPP_MAX_SWERR 64U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_DRIVEOSAPP_MAX_DIAG 64U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_DRIVEOSAPP_MAX_HWERR 0U
/* *************** END SERVICE ID for DRIVEOSAPP*************** */

/* *************** SERVICE ID for RCE*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_RCE_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_RCE_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_RCE_HSMERR_RCE_FABRIC_UE 0x010014b3U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_RCE_HSMERR_RCE_FABRIC_FUNC_UE 0x010015d8U
#define NVGUARD_SERVICE_RCE_MAX_HWERR 2U
/* *************** END SERVICE ID for RCE*************** */

/* *************** SERVICE ID for BPMP*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_BPMP_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_BPMP_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_GPU_FMON_UE 0x0100182bU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_BPMP_FABRIC_UE 0x010018a8U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_BPMP_FABRIC_FUNC_UE 0x010018a9U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_PMC_FMON_0_UE 0x010018abU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_PMC_FMON_1_UE 0x010018acU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_BPMP_CLUSTER_UE 0x010018cbU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_36_UE 0x010018ccU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_37_UE 0x010018cdU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_38_UE 0x010018ceU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_39_UE 0x010018cfU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_18_UE 0x010018d0U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_17_UE 0x010018d1U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_34_UE 0x010018d2U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_32_UE 0x010018d3U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_35_UE 0x010018d4U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_33_UE 0x010018d5U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_22_UE 0x010018d6U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_21_UE 0x010018d7U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_26_UE 0x010018d8U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_SCE_UE 0x010018d9U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_8_UE 0x010018daU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_9_UE 0x010018dbU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_RCE_UE 0x010018dcU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_11_UE 0x010018ddU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_19_UE 0x010018deU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_31_UE 0x010018dfU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_23_UE 0x010018e0U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_15_UE 0x010018e1U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_24_UE 0x010018e2U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_16_UE 0x010018e3U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_30_UE 0x010018e4U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_AON_UE 0x010018e5U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_25_UE 0x010018e6U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_7_UE 0x010018e7U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_13_UE 0x010018e8U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_10_UE 0x010018e9U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_BPMP_UE 0x010018eaU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_29_UE 0x010018ebU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_5_UE 0x010018ecU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_6_UE 0x010018edU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_20_UE 0x010018eeU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_4_UE 0x010018efU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_12_UE 0x010018f0U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_14_UE 0x010018f1U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_28_UE 0x010018f2U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_27_UE 0x010018f3U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_CAR_40_UE 0x010018f4U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_BPMP_HSMERR_BPMP_CLUSTER_CE 0x010019e2U
#define NVGUARD_SERVICE_BPMP_MAX_HWERR 48U
/* *************** END SERVICE ID for BPMP*************** */

/* *************** SERVICE ID for SPE*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_SPE_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_SPE_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SPE_HSMERR_AON_FABRIC_FUNC_UE 0x01001cc8U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SPE_HSMERR_AON_FABRIC_PG_UE 0x01001cc9U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SPE_HSMERR_AON_FABRIC_NPG_UE 0x01001ccaU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SPE_HSMERR_AON_RTC_WDT_UE 0x01001d12U
#define NVGUARD_SERVICE_SPE_MAX_HWERR 4U
/* *************** END SERVICE ID for SPE*************** */

/* *************** SERVICE ID for RCEEC*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_RCEEC_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_RCEEC_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_RCEEC_HSMERR_RCE_CLUSTER_UE 0x020022b4U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_RCEEC_HSMERR_RCE_DMA_UE 0x020022b7U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_RCEEC_HSMERR_RCE_CLUSTER_CE 0x020023d9U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_RCEEC_HSMERR_RCE_DMA_CE 0x020023daU
#define NVGUARD_SERVICE_RCEEC_MAX_HWERR 4U
/* *************** END SERVICE ID for RCEEC*************** */

/* *************** SERVICE ID for CBB*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_CBB_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_CBB_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBB_HSMERR_CBB_FABRIC_FUNC_UE 0x01002400U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBB_HSMERR_CBB_FABRIC_AXIS_0_UE 0x01002401U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBB_HSMERR_CBB_FABRIC_AXIS_1_UE 0x01002402U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBB_HSMERR_CBB_FABRIC_AXIS_2_UE 0x01002403U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBB_HSMERR_CBB_FABRIC_AXIS_3_UE 0x01002404U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBB_HSMERR_CBB_FABRIC_AXIS_4_UE 0x01002405U
#define NVGUARD_SERVICE_CBB_MAX_HWERR 6U
/* *************** END SERVICE ID for CBB*************** */

/* *************** SERVICE ID for CBBEC*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_CBBEC_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_CBBEC_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_17_UE 0x02002a06U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_16_UE 0x02002a07U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_15_UE 0x02002a08U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_14_UE 0x02002a09U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_13_UE 0x02002a0aU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_12_UE 0x02002a0bU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_11_UE 0x02002a0cU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_10_UE 0x02002a0dU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_9_UE 0x02002a0eU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_8_UE 0x02002a0fU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_7_UE 0x02002a10U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_6_UE 0x02002a11U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_5_UE 0x02002a12U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_4_UE 0x02002a13U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_3_UE 0x02002a14U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_2_UE 0x02002a15U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_1_UE 0x02002a16U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_0_UE 0x02002a17U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_18_UE 0x02002a19U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_17_CE 0x02002b40U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_16_CE 0x02002b41U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_15_CE 0x02002b42U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_14_CE 0x02002b43U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_13_CE 0x02002b44U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_12_CE 0x02002b45U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_11_CE 0x02002b46U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_10_CE 0x02002b47U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_9_CE 0x02002b48U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_8_CE 0x02002b49U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_7_CE 0x02002b4aU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_6_CE 0x02002b4bU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_5_CE 0x02002b4cU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_4_CE 0x02002b4dU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_3_CE 0x02002b4eU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_2_CE 0x02002b4fU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_1_CE 0x02002b50U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_0_CE 0x02002b51U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CBBEC_HSMERR_CBB_FABRIC_18_CE 0x02002b52U
#define NVGUARD_SERVICE_CBBEC_MAX_HWERR 38U
/* *************** END SERVICE ID for CBBEC*************** */

/* *************** SERVICE ID for SYSRAM0*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_SYSRAM0_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_SYSRAM0_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SYSRAM0_HSMERR_SYSRAM_0_UE 0x02002e64U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SYSRAM0_HSMERR_SYSRAM_0_CE 0x02002f54U
#define NVGUARD_SERVICE_SYSRAM0_MAX_HWERR 2U
/* *************** END SERVICE ID for SYSRAM0*************** */

/* *************** SERVICE ID for SYSRAM1*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_SYSRAM1_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_SYSRAM1_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SYSRAM1_HSMERR_SYSRAM_1_UE 0x02003263U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SYSRAM1_HSMERR_SYSRAM_1_CE 0x02003355U
#define NVGUARD_SERVICE_SYSRAM1_MAX_HWERR 2U
/* *************** END SERVICE ID for SYSRAM1*************** */

/* *************** SERVICE ID for SOR0*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_SOR0_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_SOR0_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SOR0_HSMERR_SOR_0_UE 0x02003701U
#define NVGUARD_SERVICE_SOR0_MAX_HWERR 1U
/* *************** END SERVICE ID for SOR0*************** */

/* *************** SERVICE ID for SOR1*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_SOR1_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_SOR1_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SOR1_HSMERR_SOR_1_UE 0x02003b00U
#define NVGUARD_SERVICE_SOR1_MAX_HWERR 1U
/* *************** END SERVICE ID for SOR1*************** */

/* *************** SERVICE ID for SOR2*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_SOR2_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_SOR2_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SOR2_HSMERR_SOR_2_UE 0x02003effU
#define NVGUARD_SERVICE_SOR2_MAX_HWERR 1U
/* *************** END SERVICE ID for SOR2*************** */

/* *************** SERVICE ID for SOR3*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_SOR3_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_SOR3_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SOR3_HSMERR_SOR_3_UE 0x020042feU
#define NVGUARD_SERVICE_SOR3_MAX_HWERR 1U
/* *************** END SERVICE ID for SOR3*************** */

/* *************** SERVICE ID for CVSRAM*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_CVSRAM_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_CVSRAM_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CVSRAM_HSMERR_CV0_SRAM_0_UE 0x0200461fU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CVSRAM_HSMERR_CV0_SRAM_1_UE 0x02004620U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CVSRAM_HSMERR_CV0_SRAM_2_UE 0x02004621U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CVSRAM_HSMERR_CV0_SRAM_3_UE 0x02004622U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CVSRAM_HSMERR_CV0_SRAM_0_CE 0x02004758U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CVSRAM_HSMERR_CV0_SRAM_1_CE 0x02004759U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CVSRAM_HSMERR_CV0_SRAM_2_CE 0x0200475aU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CVSRAM_HSMERR_CV0_SRAM_3_CE 0x0200475bU
#define NVGUARD_SERVICE_CVSRAM_MAX_HWERR 8U
/* *************** END SERVICE ID for CVSRAM*************** */

/* *************** SERVICE ID for PVAEC*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_PVAEC_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_PVAEC_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_PVAEC_HSMERR_PVA_0_UE 0x02004b10U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_PVAEC_HSMERR_PVA_1_UE 0x02004b11U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_PVAEC_HSMERR_PVA_0_CE 0x02004bfbU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_PVAEC_HSMERR_PVA_1_CE 0x02004bfcU
#define NVGUARD_SERVICE_PVAEC_MAX_HWERR 4U
/* *************** END SERVICE ID for PVAEC*************** */

/* *************** SERVICE ID for MC*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_MC_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_MC_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_15_UE 0x02004e2eU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_14_UE 0x02004e2fU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_13_UE 0x02004e30U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_12_UE 0x02004e31U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_11_UE 0x02004e32U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_10_UE 0x02004e33U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_9_UE 0x02004e34U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_8_UE 0x02004e35U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_7_UE 0x02004e36U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_6_UE 0x02004e37U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_5_UE 0x02004e38U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_4_UE 0x02004e39U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_3_UE 0x02004e3aU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_2_UE 0x02004e3bU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_1_UE 0x02004e3cU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_0_UE 0x02004e3dU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_HUB_3_UE 0x02004e4eU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_HUB_2_UE 0x02004e4fU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_HUB_1_UE 0x02004e50U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_HUB_0_UE 0x02004e51U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_HUBC_UE 0x02004e58U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_15_CE 0x02004f5eU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_14_CE 0x02004f5fU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_13_CE 0x02004f60U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_12_CE 0x02004f61U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_11_CE 0x02004f62U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_10_CE 0x02004f63U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_9_CE 0x02004f64U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_8_CE 0x02004f65U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_7_CE 0x02004f66U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_6_CE 0x02004f67U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_5_CE 0x02004f68U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_4_CE 0x02004f69U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_3_CE 0x02004f6aU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_2_CE 0x02004f6bU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_1_CE 0x02004f6cU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_0_CE 0x02004f6dU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_HUB_3_CE 0x02004f7eU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_HUB_2_CE 0x02004f7fU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_HUB_1_CE 0x02004f80U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_HUB_0_CE 0x02004f81U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MC_HSMERR_MC_HUBC_CE 0x02004f88U
#define NVGUARD_SERVICE_MC_MAX_HWERR 42U
/* *************** END SERVICE ID for MC*************** */

/* *************** SERVICE ID for MCF*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_MCF_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_MCF_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MCF_HSMERR_MCF_SLICE_3_UE 0x02005259U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MCF_HSMERR_MCF_SLICE_2_UE 0x0200525aU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MCF_HSMERR_MCF_SLICE_1_UE 0x0200525bU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MCF_HSMERR_MCF_SLICE_0_UE 0x0200525cU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MCF_HSMERR_MCF_IREQX_UE 0x0200525dU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MCF_HSMERR_MCF_IRSPX_1_UE 0x0200525eU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MCF_HSMERR_MCF_IRSPX_0_UE 0x0200525fU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MCF_HSMERR_MCF_OREQX_1_UE 0x02005260U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MCF_HSMERR_MCF_OREQX_0_UE 0x02005261U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MCF_HSMERR_MCF_ORSPX_UE 0x02005262U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MCF_HSMERR_MCF_SLICE_3_CE 0x02005389U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MCF_HSMERR_MCF_SLICE_2_CE 0x0200538aU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MCF_HSMERR_MCF_SLICE_1_CE 0x0200538bU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MCF_HSMERR_MCF_SLICE_0_CE 0x0200538cU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MCF_HSMERR_MCF_IREQX_CE 0x0200538dU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MCF_HSMERR_MCF_IRSPX_1_CE 0x0200538eU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MCF_HSMERR_MCF_IRSPX_0_CE 0x0200538fU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MCF_HSMERR_MCF_OREQX_1_CE 0x02005390U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MCF_HSMERR_MCF_OREQX_0_CE 0x02005391U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MCF_HSMERR_MCF_ORSPX_CE 0x02005394U
#define NVGUARD_SERVICE_MCF_MAX_HWERR 20U
/* *************** END SERVICE ID for MCF*************** */

/* *************** SERVICE ID for SPI1*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_SPI1_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_SPI1_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SPI1_HSMERR_SPI_1_UE 0x01005514U
#define NVGUARD_SERVICE_SPI1_MAX_HWERR 1U
/* *************** END SERVICE ID for SPI1*************** */

/* *************** SERVICE ID for SPI2*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_SPI2_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_SPI2_DIAG_E2E_CHECK 0x02205800U
#define NVGUARD_SERVICE_SPI2_MAX_DIAG 1U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SPI2_HSMERR_SPI_2_UE 0x02005915U
#define NVGUARD_SERVICE_SPI2_MAX_HWERR 1U
/* *************** END SERVICE ID for SPI2*************** */

/* *************** SERVICE ID for SPI3*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_SPI3_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_SPI3_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SPI3_HSMERR_SPI_3_UE 0x01005d13U
#define NVGUARD_SERVICE_SPI3_MAX_HWERR 1U
/* *************** END SERVICE ID for SPI3*************** */

/* *************** SERVICE ID for VICEC*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_VICEC_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_VICEC_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_VICEC_HSMERR_VIC_UE 0x0200630fU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_VICEC_HSMERR_VIC_CE 0x020063faU
#define NVGUARD_SERVICE_VICEC_MAX_HWERR 2U
/* *************** END SERVICE ID for VICEC*************** */

/* *************** SERVICE ID for NVLINK*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_NVLINK_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_NVLINK_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_NVLINK_HSMERR_NVLINK_INTR_UE 0x0100651dU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_NVLINK_HSMERR_MSS_NVLINK_0_INTR_CE 0x010065ffU
#define NVGUARD_SERVICE_NVLINK_MAX_HWERR 2U
/* *************** END SERVICE ID for NVLINK*************** */

/* *************** SERVICE ID for NVLINKEC*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_NVLINKEC_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_NVLINKEC_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_NVLINKEC_HSMERR_MSS_NVLINK_4_UE 0x02006a52U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_NVLINKEC_HSMERR_MSS_NVLINK_3_UE 0x02006a53U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_NVLINKEC_HSMERR_MSS_NVLINK_2_UE 0x02006a54U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_NVLINKEC_HSMERR_MSS_NVLINK_1_UE 0x02006a55U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_NVLINKEC_HSMERR_MSS_NVLINK_0_UE 0x02006a56U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_NVLINKEC_HSMERR_MSS_NVLINK_4_CE 0x02006b82U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_NVLINKEC_HSMERR_MSS_NVLINK_3_CE 0x02006b83U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_NVLINKEC_HSMERR_MSS_NVLINK_2_CE 0x02006b84U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_NVLINKEC_HSMERR_MSS_NVLINK_1_CE 0x02006b85U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_NVLINKEC_HSMERR_MSS_NVLINK_0_CE 0x02006b86U
#define NVGUARD_SERVICE_NVLINKEC_MAX_HWERR 10U
/* *************** END SERVICE ID for NVLINKEC*************** */

/* *************** SERVICE ID for CVNOCEC*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_CVNOCEC_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_CVNOCEC_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CVNOCEC_HSMERR_CV0_FABRIC_0_UE 0x02006e1dU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CVNOCEC_HSMERR_CV0_FABRIC_0_CE 0x02006f56U
#define NVGUARD_SERVICE_CVNOCEC_MAX_HWERR 2U
/* *************** END SERVICE ID for CVNOCEC*************** */

/* *************** SERVICE ID for GPIO*************** */
/*  IDs for SW Error Handler */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_GPIO_SWERR_LOOPBACK_ERR 0x01107000U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_GPIO_SWERR_REG_CHECK_ERR 0x01107001U
#define NVGUARD_SERVICE_GPIO_MAX_SWERR 2U
/* IDs for Diagnostics Test Services */
/** DESCRIPTION : I/O loopback test */
#define NVGUARD_SERVICE_GPIO_DIAG_LOOPBACK 0x01207000U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_GPIO_DIAG_REG_CHECK 0x01207001U
#define NVGUARD_SERVICE_GPIO_MAX_DIAG 2U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_GPIO_MAX_HWERR 0U
/* *************** END SERVICE ID for GPIO*************** */

/* *************** SERVICE ID for PCIE0*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_PCIE0_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_PCIE0_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_PCIE0_HSMERR_PCIE_C0_UE 0x0100751eU
#define NVGUARD_SERVICE_PCIE0_MAX_HWERR 1U
/* *************** END SERVICE ID for PCIE0*************** */

/* *************** SERVICE ID for PCIE1*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_PCIE1_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_PCIE1_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_PCIE1_HSMERR_PCIE_C1_UE 0x0100791fU
#define NVGUARD_SERVICE_PCIE1_MAX_HWERR 1U
/* *************** END SERVICE ID for PCIE1*************** */

/* *************** SERVICE ID for PCIE2*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_PCIE2_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_PCIE2_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_PCIE2_HSMERR_PCIE_C2_UE 0x01007d20U
#define NVGUARD_SERVICE_PCIE2_MAX_HWERR 1U
/* *************** END SERVICE ID for PCIE2*************** */

/* *************** SERVICE ID for PCIE3*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_PCIE3_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_PCIE3_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_PCIE3_HSMERR_PCIE_C3_UE 0x01008121U
#define NVGUARD_SERVICE_PCIE3_MAX_HWERR 1U
/* *************** END SERVICE ID for PCIE3*************** */

/* *************** SERVICE ID for PCIE4*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_PCIE4_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_PCIE4_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_PCIE4_HSMERR_PCIE_C4_UE 0x01008522U
#define NVGUARD_SERVICE_PCIE4_MAX_HWERR 1U
/* *************** END SERVICE ID for PCIE4*************** */

/* *************** SERVICE ID for PCIE5*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_PCIE5_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_PCIE5_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_PCIE5_HSMERR_PCIE_C5_UE 0x01008923U
#define NVGUARD_SERVICE_PCIE5_MAX_HWERR 1U
/* *************** END SERVICE ID for PCIE5*************** */

/* *************** SERVICE ID for HOST1XEC*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_HOST1XEC_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_HOST1XEC_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_HOST1XEC_HSMERR_HOST1X_UE 0x02008f07U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_HOST1XEC_HSMERR_HOST1X_CE 0x02008ff2U
#define NVGUARD_SERVICE_HOST1XEC_MAX_HWERR 2U
/* *************** END SERVICE ID for HOST1XEC*************** */

/* *************** SERVICE ID for MISC*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_MISC_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_MISC_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MISC_HSMERR_MISC_UE 0x02009308U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MISC_HSMERR_MISC_CE 0x020093f3U
#define NVGUARD_SERVICE_MISC_MAX_HWERR 2U
/* *************** END SERVICE ID for MISC*************** */

/* *************** SERVICE ID for PVA0*************** */
/*  IDs for SW Error Handler */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_PVA0_SWERR_SWERR_PANIC 0x01109400U
#define NVGUARD_SERVICE_PVA0_MAX_SWERR 1U
/* IDs for Diagnostics Test Services */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_PVA0_DIAG_SDL_TEST0 0x01209400U
#define NVGUARD_SERVICE_PVA0_MAX_DIAG 1U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_PVA0_MAX_HWERR 0U
/* *************** END SERVICE ID for PVA0*************** */

/* *************** SERVICE ID for PVA1*************** */
/*  IDs for SW Error Handler */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_PVA1_SWERR_SWERR_PANIC 0x01109800U
#define NVGUARD_SERVICE_PVA1_MAX_SWERR 1U
/* IDs for Diagnostics Test Services */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_PVA1_DIAG_SDL_TEST0 0x01209800U
#define NVGUARD_SERVICE_PVA1_MAX_DIAG 1U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_PVA1_MAX_HWERR 0U
/* *************** END SERVICE ID for PVA1*************** */

/* *************** SERVICE ID for CVNOC*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_CVNOC_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_CVNOC_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CVNOC_HSMERR_CV0_FABRIC_1_UE 0x01009c1eU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CVNOC_HSMERR_CV0_FABRIC_FUNC_UE 0x01009d57U
#define NVGUARD_SERVICE_CVNOC_MAX_HWERR 2U
/* *************** END SERVICE ID for CVNOC*************** */

/* *************** SERVICE ID for DGPU*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_DGPU_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
/** DESCRIPTION : Periodic diag for dGPU */
#define NVGUARD_SERVICE_DGPU_DIAG_PERIODIC_MONITOR 0x0120a000U
#define NVGUARD_SERVICE_DGPU_MAX_DIAG 1U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_DGPU_HSMERR_PAD_DGPU_IN_UE 0x0100a11aU
#define NVGUARD_SERVICE_DGPU_MAX_HWERR 1U
/* *************** END SERVICE ID for DGPU*************** */

/* *************** SERVICE ID for PINMUX_PADRING*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_PINMUX_PADRING_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
/** DESCRIPTION : Periodic diagnostics of Pinmux configuration */
#define NVGUARD_SERVICE_PINMUX_PADRING_DIAG_PERIODIC_CHECK 0x0220a400U
#define NVGUARD_SERVICE_PINMUX_PADRING_MAX_DIAG 1U
/* IDs for HW Error Handlers */
/** DESCRIPTION : Pinmux PAD register parity error   */
#define NVGUARD_SERVICE_PINMUX_PADRING_HSMERR_PADCTL_A16_UE 0x0200a728U
/** DESCRIPTION : Pinmux PAD register parity error   */
#define NVGUARD_SERVICE_PINMUX_PADRING_HSMERR_PADCTL_A12_UE 0x0200a729U
#define NVGUARD_SERVICE_PINMUX_PADRING_MAX_HWERR 2U
/* *************** END SERVICE ID for PINMUX_PADRING*************** */

/* *************** SERVICE ID for DLAEC*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_DLAEC_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_DLAEC_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_DLAEC_HSMERR_NVDLA_0_UE 0x0200ab0bU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_DLAEC_HSMERR_NVDLA_1_UE 0x0200ab0cU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_DLAEC_HSMERR_NVDLA_0_CE 0x0200abf6U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_DLAEC_HSMERR_NVDLA_1_CE 0x0200abf7U
#define NVGUARD_SERVICE_DLAEC_MAX_HWERR 4U
/* *************** END SERVICE ID for DLAEC*************** */

/* *************** SERVICE ID for NVENCEC*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_NVENCEC_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_NVENCEC_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_NVENCEC_HSMERR_NVENC_0_UE 0x0200af0dU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_NVENCEC_HSMERR_NVENC_1_UE 0x0200af0eU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_NVENCEC_HSMERR_NVENC_0_CE 0x0200aff8U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_NVENCEC_HSMERR_NVENC_1_CE 0x0200aff9U
#define NVGUARD_SERVICE_NVENCEC_MAX_HWERR 4U
/* *************** END SERVICE ID for NVENCEC*************** */

/* *************** SERVICE ID for CCPLEX*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_CCPLEX_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
/** DESCRIPTION : test for permanent fault diagnostic of FPS in CCPLEX */
#define NVGUARD_SERVICE_CCPLEX_DIAG_FPS_PF_TEST0 0x0120b000U
/** DESCRIPTION : test for permanent fault diagnostic of FPS in CCPLEX */
#define NVGUARD_SERVICE_CCPLEX_DIAG_FPS_PF_TEST1 0x0120b001U
/** DESCRIPTION : test for permanent fault diagnostic of FPS in CCPLEX */
#define NVGUARD_SERVICE_CCPLEX_DIAG_FPS_PF_TEST2 0x0120b002U
/** DESCRIPTION : test for permanent fault diagnostic of FPS in CCPLEX */
#define NVGUARD_SERVICE_CCPLEX_DIAG_FPS_PF_TEST3 0x0120b003U
/** DESCRIPTION : test for permanent fault diagnostic of FPS in CCPLEX */
#define NVGUARD_SERVICE_CCPLEX_DIAG_FPS_PF_TEST4 0x0120b004U
/** DESCRIPTION : test for permanent fault diagnostic of FPS in CCPLEX */
#define NVGUARD_SERVICE_CCPLEX_DIAG_FPS_PF_TEST5 0x0120b005U
/** DESCRIPTION : test for permanent fault diagnostic of FPS in CCPLEX */
#define NVGUARD_SERVICE_CCPLEX_DIAG_FPS_PF_TEST6 0x0120b006U
/** DESCRIPTION : test for permanent fault diagnostic of FPS in CCPLEX */
#define NVGUARD_SERVICE_CCPLEX_DIAG_FPS_PF_TEST7 0x0120b007U
/** DESCRIPTION : test for GIC HW diagnostic in CCPLEX */
#define NVGUARD_SERVICE_CCPLEX_DIAG_GIC_SDL_TEST0 0x0120b008U
/** DESCRIPTION : test for GIC HW diagnostic in CCPLEX */
#define NVGUARD_SERVICE_CCPLEX_DIAG_GIC_SDL_TEST1 0x0120b009U
/** DESCRIPTION : test for GIC HW diagnostic in CCPLEX */
#define NVGUARD_SERVICE_CCPLEX_DIAG_GIC_SDL_TEST2 0x0120b00aU
/** DESCRIPTION : test for GIC HW diagnostic in CCPLEX */
#define NVGUARD_SERVICE_CCPLEX_DIAG_GIC_SDL_TEST3 0x0120b00bU
/** DESCRIPTION : test for GIC HW diagnostic in CCPLEX */
#define NVGUARD_SERVICE_CCPLEX_DIAG_GIC_SDL_TEST4 0x0120b00cU
/** DESCRIPTION : test for GIC HW diagnostic in CCPLEX */
#define NVGUARD_SERVICE_CCPLEX_DIAG_GIC_SDL_TEST5 0x0120b00dU
/** DESCRIPTION : test for GIC HW diagnostic in CCPLEX */
#define NVGUARD_SERVICE_CCPLEX_DIAG_GIC_SDL_TEST6 0x0120b00eU
/** DESCRIPTION : test for GIC HW diagnostic in CCPLEX */
#define NVGUARD_SERVICE_CCPLEX_DIAG_GIC_SDL_TEST7 0x0120b00fU
#define NVGUARD_SERVICE_CCPLEX_MAX_DIAG 16U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CCPLEX_HSMERR_CCPLEX_UE 0x0100b0fcU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_CCPLEX_HSMERR_CCPLEX_CE 0x0100b1e3U
#define NVGUARD_SERVICE_CCPLEX_MAX_HWERR 2U
/* *************** END SERVICE ID for CCPLEX*************** */

/* *************** SERVICE ID for SE*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_SE_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
/** DESCRIPTION : SE periodic diagnostic */
#define NVGUARD_SERVICE_SE_DIAG_SE_DIAGNOSTICS 0x0120b400U
#define NVGUARD_SERVICE_SE_MAX_DIAG 1U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_SE_MAX_HWERR 0U
/* *************** END SERVICE ID for SE*************** */

/* *************** SERVICE ID for TOP_GPCDMA*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_TOP_GPCDMA_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_TOP_GPCDMA_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TOP_GPCDMA_HSMERR_GPCDMA_UE 0x0200bb06U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TOP_GPCDMA_HSMERR_GPCDMA_CE 0x0200bbf0U
#define NVGUARD_SERVICE_TOP_GPCDMA_MAX_HWERR 2U
/* *************** END SERVICE ID for TOP_GPCDMA*************** */

/* *************** SERVICE ID for WDT0*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_WDT0_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_WDT0_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_WDT0_HSMERR_TOP_TKE_0_UE 0x0100bd18U
#define NVGUARD_SERVICE_WDT0_MAX_HWERR 1U
/* *************** END SERVICE ID for WDT0*************** */

/* *************** SERVICE ID for WDT2*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_WDT2_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_WDT2_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_WDT2_HSMERR_TOP_TKE_2_UE 0x0100c116U
#define NVGUARD_SERVICE_WDT2_MAX_HWERR 1U
/* *************** END SERVICE ID for WDT2*************** */

/* *************** SERVICE ID for WDT1*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_WDT1_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_WDT1_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_WDT1_HSMERR_TOP_TKE_1_UE 0x0100c517U
#define NVGUARD_SERVICE_WDT1_MAX_HWERR 1U
/* *************** END SERVICE ID for WDT1*************** */

/* *************** SERVICE ID for SMMUEC*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_SMMUEC_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_SMMUEC_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SMMUEC_HSMERR_TCU_WRAP_0_UE 0x0200ca57U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_SMMUEC_HSMERR_TCU_WRAP_0_CE 0x0200cb87U
#define NVGUARD_SERVICE_SMMUEC_MAX_HWERR 2U
/* *************** END SERVICE ID for SMMUEC*************** */

/* *************** SERVICE ID for SMMU*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_SMMU_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_SMMU_DIAG_MMU500_PARITY 0x0120cc00U
#define NVGUARD_SERVICE_SMMU_MAX_DIAG 1U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_SMMU_MAX_HWERR 0U
/* *************** END SERVICE ID for SMMU*************** */

/* *************** SERVICE ID for WDT5*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_WDT5_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_WDT5_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_WDT5_HSMERR_AON_TKE_UE 0x0100d0c5U
#define NVGUARD_SERVICE_WDT5_MAX_HWERR 1U
/* *************** END SERVICE ID for WDT5*************** */

/* *************** SERVICE ID for WDT6*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_WDT6_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_WDT6_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_WDT6_HSMERR_RCE_TKE_UE 0x0100d4b2U
#define NVGUARD_SERVICE_WDT6_MAX_HWERR 1U
/* *************** END SERVICE ID for WDT6*************** */

/* *************** SERVICE ID for IGPU*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_IGPU_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
/** DESCRIPTION : Periodic diag for iGPU */
#define NVGUARD_SERVICE_IGPU_DIAG_PERIODIC_MONITOR 0x0120d800U
#define NVGUARD_SERVICE_IGPU_MAX_DIAG 1U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_IGPU_MAX_HWERR 0U
/* *************** END SERVICE ID for IGPU*************** */

/* *************** SERVICE ID for XUSB*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_XUSB_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_XUSB_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_XUSB_HSMERR_XUSB_UE 0x0100dcc3U
#define NVGUARD_SERVICE_XUSB_MAX_HWERR 1U
/* *************** END SERVICE ID for XUSB*************** */

/* *************** SERVICE ID for DRAMECC*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_DRAMECC_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
/** DESCRIPTION : DRAM ECC startup diagnostic test */
#define NVGUARD_SERVICE_DRAMECC_DIAG_STARTUP_TEST 0x0220e000U
#define NVGUARD_SERVICE_DRAMECC_MAX_DIAG 1U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_DRAMECC_HSMERR_DRAM_ECC_1_UE 0x0200e11bU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_DRAMECC_HSMERR_DRAM_ECC_0_UE 0x0200e11cU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_DRAMECC_HSMERR_EMC_INTR_CE 0x0200e1feU
#define NVGUARD_SERVICE_DRAMECC_MAX_HWERR 3U
/* *************** END SERVICE ID for DRAMECC*************** */

/* *************** SERVICE ID for MSS*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_MSS_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_MSS_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MSS_HSMERR_MSS_QUAL_UE 0x0200e62dU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MSS_HSMERR_MSS_SBS_UE 0x0200e665U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MSS_HSMERR_AON_MSS_UE 0x0200e6aaU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MSS_HSMERR_MSS_QUAL_CE 0x0200e75cU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MSS_HSMERR_MSS_SBS_CE 0x0200e796U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_MSS_HSMERR_AON_MSS_CE 0x0200e797U
#define NVGUARD_SERVICE_MSS_MAX_HWERR 6U
/* *************** END SERVICE ID for MSS*************** */

/* *************** SERVICE ID for NVCSI*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_NVCSI_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_NVCSI_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_NVCSI_HSMERR_NVCSI_UE 0x0200eb0aU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_NVCSI_HSMERR_NVCSI_ERR_WITH_THRESHOLD 0x0200ebf5U
#define NVGUARD_SERVICE_NVCSI_MAX_HWERR 2U
/* *************** END SERVICE ID for NVCSI*************** */

/* *************** SERVICE ID for DISPLAYEC*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_DISPLAYEC_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_DISPLAYEC_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_DISPLAYEC_HSMERR_DISPLAY_UE 0x0200eefdU
#define NVGUARD_SERVICE_DISPLAYEC_MAX_HWERR 1U
/* *************** END SERVICE ID for DISPLAYEC*************** */

/* *************** SERVICE ID for DISPLAY*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_DISPLAY_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_DISPLAY_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_DISPLAY_HSMERR_DISPLAY_HEAD3_INTR_UE 0x0100f1e4U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_DISPLAY_HSMERR_DISPLAY_HEAD2_INTR_UE 0x0100f1e5U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_DISPLAY_HSMERR_DISPLAY_HEAD1_INTR_UE 0x0100f1e6U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_DISPLAY_HSMERR_DISPLAY_HEAD0_INTR_UE 0x0100f1e7U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_DISPLAY_HSMERR_SOR_3_INTR_UE 0x0100f1e8U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_DISPLAY_HSMERR_SOR_2_INTR_UE 0x0100f1e9U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_DISPLAY_HSMERR_SOR_1_INTR_UE 0x0100f1eaU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_DISPLAY_HSMERR_SOR_0_INTR_UE 0x0100f1ebU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_DISPLAY_HSMERR_DPAUX_3_UE 0x0100f1ecU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_DISPLAY_HSMERR_DPAUX_2_UE 0x0100f1edU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_DISPLAY_HSMERR_DPAUX_1_UE 0x0100f1eeU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_DISPLAY_HSMERR_DPAUX_0_UE 0x0100f1efU
#define NVGUARD_SERVICE_DISPLAY_MAX_HWERR 12U
/* *************** END SERVICE ID for DISPLAY*************** */

/* *************** SERVICE ID for ISP*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_ISP_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_ISP_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_ISP_HSMERR_ISP_THI_UE 0x0200f709U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_ISP_HSMERR_ISP_THI_CE 0x0200f7f4U
#define NVGUARD_SERVICE_ISP_MAX_HWERR 2U
/* *************** END SERVICE ID for ISP*************** */

/* *************** SERVICE ID for TSA*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_TSA_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_TSA_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_55_UE 0x0200fa6eU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_54_UE 0x0200fa6fU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_53_UE 0x0200fa70U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_52_UE 0x0200fa71U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_51_UE 0x0200fa72U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_50_UE 0x0200fa73U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_49_UE 0x0200fa74U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_48_UE 0x0200fa75U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_47_UE 0x0200fa76U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_46_UE 0x0200fa77U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_45_UE 0x0200fa78U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_44_UE 0x0200fa79U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_43_UE 0x0200fa7aU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_42_UE 0x0200fa7bU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_41_UE 0x0200fa7cU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_40_UE 0x0200fa7dU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_39_UE 0x0200fa7eU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_38_UE 0x0200fa7fU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_37_UE 0x0200fa80U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_36_UE 0x0200fa81U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_35_UE 0x0200fa82U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_34_UE 0x0200fa83U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_33_UE 0x0200fa84U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_32_UE 0x0200fa85U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_31_UE 0x0200fa86U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_30_UE 0x0200fa87U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_29_UE 0x0200fa88U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_28_UE 0x0200fa89U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_27_UE 0x0200fa8aU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_26_UE 0x0200fa8bU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_25_UE 0x0200fa8cU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_24_UE 0x0200fa8dU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_23_UE 0x0200fa8eU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_22_UE 0x0200fa8fU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_21_UE 0x0200fa90U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_20_UE 0x0200fa91U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_19_UE 0x0200fa92U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_18_UE 0x0200fa93U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_17_UE 0x0200fa94U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_16_UE 0x0200fa95U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_15_UE 0x0200fa96U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_14_UE 0x0200fa97U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_13_UE 0x0200fa98U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_12_UE 0x0200fa99U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_11_UE 0x0200fa9aU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_10_UE 0x0200fa9bU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_9_UE 0x0200fa9cU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_8_UE 0x0200fa9dU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_7_UE 0x0200fa9eU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_6_UE 0x0200fa9fU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_5_UE 0x0200faa0U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_4_UE 0x0200faa1U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_3_UE 0x0200faa2U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_2_UE 0x0200faa3U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_1_UE 0x0200faa4U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_0_UE 0x0200faa5U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_55_CE 0x0200fba0U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_54_CE 0x0200fba1U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_53_CE 0x0200fba2U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_52_CE 0x0200fba3U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_51_CE 0x0200fba4U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_50_CE 0x0200fba5U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_49_CE 0x0200fba6U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_48_CE 0x0200fba7U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_47_CE 0x0200fba8U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_46_CE 0x0200fba9U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_45_CE 0x0200fbaaU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_44_CE 0x0200fbabU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_43_CE 0x0200fbacU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_42_CE 0x0200fbadU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_41_CE 0x0200fbaeU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_40_CE 0x0200fbafU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_39_CE 0x0200fbb0U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_38_CE 0x0200fbb1U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_37_CE 0x0200fbb2U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_36_CE 0x0200fbb3U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_35_CE 0x0200fbb4U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_34_CE 0x0200fbb5U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_33_CE 0x0200fbb6U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_32_CE 0x0200fbb7U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_31_CE 0x0200fbb8U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_30_CE 0x0200fbb9U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_29_CE 0x0200fbbaU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_28_CE 0x0200fbbbU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_27_CE 0x0200fbbcU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_26_CE 0x0200fbbdU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_25_CE 0x0200fbbeU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_24_CE 0x0200fbbfU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_23_CE 0x0200fbc0U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_22_CE 0x0200fbc1U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_21_CE 0x0200fbc2U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_20_CE 0x0200fbc3U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_19_CE 0x0200fbc4U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_18_CE 0x0200fbc5U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_17_CE 0x0200fbc6U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_16_CE 0x0200fbc7U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_15_CE 0x0200fbc8U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_14_CE 0x0200fbc9U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_13_CE 0x0200fbcaU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_12_CE 0x0200fbcbU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_11_CE 0x0200fbccU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_10_CE 0x0200fbcdU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_9_CE 0x0200fbceU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_8_CE 0x0200fbcfU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_7_CE 0x0200fbd0U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_6_CE 0x0200fbd1U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_5_CE 0x0200fbd2U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_4_CE 0x0200fbd3U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_3_CE 0x0200fbd4U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_2_CE 0x0200fbd5U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_1_CE 0x0200fbd6U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_TSA_HSMERR_TSA_NODE_0_CE 0x0200fbd7U
#define NVGUARD_SERVICE_TSA_MAX_HWERR 112U
/* *************** END SERVICE ID for TSA*************** */

/* *************** SERVICE ID for EMC*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_EMC_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_EMC_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_15_UE 0x0200fe3eU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_14_UE 0x0200fe3fU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_13_UE 0x0200fe40U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_12_UE 0x0200fe41U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_11_UE 0x0200fe42U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_10_UE 0x0200fe43U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_9_UE 0x0200fe44U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_8_UE 0x0200fe45U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_7_UE 0x0200fe46U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_6_UE 0x0200fe47U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_5_UE 0x0200fe48U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_4_UE 0x0200fe49U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_3_UE 0x0200fe4aU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_2_UE 0x0200fe4bU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_1_UE 0x0200fe4cU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_0_UE 0x0200fe4dU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_15_CE 0x0200ff6eU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_14_CE 0x0200ff6fU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_13_CE 0x0200ff70U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_12_CE 0x0200ff71U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_11_CE 0x0200ff72U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_10_CE 0x0200ff73U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_9_CE 0x0200ff74U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_8_CE 0x0200ff75U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_7_CE 0x0200ff76U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_6_CE 0x0200ff77U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_5_CE 0x0200ff78U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_4_CE 0x0200ff79U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_3_CE 0x0200ff7aU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_2_CE 0x0200ff7bU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_1_CE 0x0200ff7cU
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_EMC_HSMERR_EMC_0_CE 0x0200ff7dU
#define NVGUARD_SERVICE_EMC_MAX_HWERR 32U
/* *************** END SERVICE ID for EMC*************** */

/* *************** SERVICE ID for HOST1X*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_HOST1X_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_HOST1X_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_HOST1X_HSMERR_HOST1X_INTR_UE 0x010101f1U
#define NVGUARD_SERVICE_HOST1X_MAX_HWERR 1U
/* *************** END SERVICE ID for HOST1X*************** */

/* *************** SERVICE ID for VIC*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_VIC_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_VIC_DIAG_SDL_TEST0 0x01210400U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_VIC_DIAG_SDL_TEST1 0x01210401U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_VIC_DIAG_SDL_TEST2 0x01210402U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_VIC_DIAG_SDL_TEST3 0x01210403U
#define NVGUARD_SERVICE_VIC_MAX_DIAG 4U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_VIC_MAX_HWERR 0U
/* *************** END SERVICE ID for VIC*************** */

/* *************** SERVICE ID for VI*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_VI_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_VI_MAX_DIAG 0U
/* IDs for HW Error Handlers */
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_VI_HSMERR_VI_UE 0x02010b19U
/** DESCRIPTION :   */
#define NVGUARD_SERVICE_VI_HSMERR_VI_ERR_WITH_THRESHOLD 0x02010bfdU
#define NVGUARD_SERVICE_VI_MAX_HWERR 2U
/* *************** END SERVICE ID for VI*************** */

/* *************** SERVICE ID for NVENCA*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_NVENCA_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_NVENCA_DIAG_STEREODISPARITY_PERIODIC_TEST 0x01210c00U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_NVENCA_DIAG_OPTICALFLOW_PERIODIC_TEST 0x01210c01U
#define NVGUARD_SERVICE_NVENCA_MAX_DIAG 2U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_NVENCA_MAX_HWERR 0U
/* *************** END SERVICE ID for NVENCA*************** */

/* *************** SERVICE ID for NVENCB*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_NVENCB_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_NVENCB_DIAG_STEREODISPARITY_PERIODIC_TEST 0x01211000U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_NVENCB_DIAG_OPTICALFLOW_PERIODIC_TEST 0x01211001U
#define NVGUARD_SERVICE_NVENCB_MAX_DIAG 2U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_NVENCB_MAX_HWERR 0U
/* *************** END SERVICE ID for NVENCB*************** */

/* *************** SERVICE ID for DLA0*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_DLA0_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_DLA0_DIAG_PERMANENT_FAULT_DIAGNOSTIC 0x01211400U
#define NVGUARD_SERVICE_DLA0_MAX_DIAG 1U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_DLA0_MAX_HWERR 0U
/* *************** END SERVICE ID for DLA0*************** */

/* *************** SERVICE ID for DLA1*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_DLA1_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_DLA1_DIAG_PERMANENT_FAULT_DIAGNOSTIC 0x01211800U
#define NVGUARD_SERVICE_DLA1_MAX_DIAG 1U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_DLA1_MAX_HWERR 0U
/* *************** END SERVICE ID for DLA1*************** */

/* *************** SERVICE ID for NVTMON_TEGRA*************** */
/*  IDs for SW Error Handler */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_NVTMON_TEGRA_SWERR_READBACK_CHECK 0x01111c00U
#define NVGUARD_SERVICE_NVTMON_TEGRA_MAX_SWERR 1U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_NVTMON_TEGRA_MAX_DIAG 0U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_NVTMON_TEGRA_MAX_HWERR 0U
/* *************** END SERVICE ID for NVTMON_TEGRA*************** */

/* *************** SERVICE ID for TIMERS*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_TIMERS_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_TIMERS_DIAG_TSC_MONITOR 0x01212000U
#define NVGUARD_SERVICE_TIMERS_MAX_DIAG 1U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_TIMERS_MAX_HWERR 0U
/* *************** END SERVICE ID for TIMERS*************** */

/* *************** SERVICE ID for PWM_FAN*************** */
/*  IDs for SW Error Handler */
#define NVGUARD_SERVICE_PWM_FAN_MAX_SWERR 0U
/* IDs for Diagnostics Test Services */
/** DESCRIPTION : Periodic test for Fan1(push) Fault */
#define NVGUARD_SERVICE_PWM_FAN_DIAG_PUSH_FAN_FAULT 0x01212400U
/** DESCRIPTION : Periodic test for Fan2(pull) Fault */
#define NVGUARD_SERVICE_PWM_FAN_DIAG_PULL_FAN_FAULT 0x01212401U
#define NVGUARD_SERVICE_PWM_FAN_MAX_DIAG 2U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_PWM_FAN_MAX_HWERR 0U
/* *************** END SERVICE ID for PWM_FAN*************** */

/* *************** SERVICE ID for CAN0*************** */
/*  IDs for SW Error Handler */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_CAN0_SWERR_MRAM_TIMEOUT 0x01112800U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_CAN0_SWERR_LOOPBACK_ERR 0x01112801U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_CAN0_SWERR_FUNCTIONAL_ERR 0x01112802U
#define NVGUARD_SERVICE_CAN0_MAX_SWERR 3U
/* IDs for Diagnostics Test Services */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_CAN0_DIAG_CONFIGCHK_ERR 0x01212800U
#define NVGUARD_SERVICE_CAN0_MAX_DIAG 1U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_CAN0_MAX_HWERR 0U
/* *************** END SERVICE ID for CAN0*************** */

/* *************** SERVICE ID for CAN1*************** */
/*  IDs for SW Error Handler */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_CAN1_SWERR_MRAM_TIMEOUT 0x01112c00U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_CAN1_SWERR_LOOPBACK_ERR 0x01112c01U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_CAN1_SWERR_FUNCTIONAL_ERR 0x01112c02U
#define NVGUARD_SERVICE_CAN1_MAX_SWERR 3U
/* IDs for Diagnostics Test Services */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_CAN1_DIAG_CONFIGCHK_ERR 0x01212c00U
#define NVGUARD_SERVICE_CAN1_MAX_DIAG 1U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_CAN1_MAX_HWERR 0U
/* *************** END SERVICE ID for CAN1*************** */

/* *************** SERVICE ID for IGPU_HOST*************** */
/*  IDs for SW Error Handler */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_HOST_SWERR_PFIFO_BIND_ERROR 0x01113000U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_HOST_SWERR_PFIFO_SCHED_ERROR 0x01113001U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_HOST_SWERR_PFIFO_CHSW_ERROR 0x01113002U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_HOST_SWERR_PFIFO_MEMOP_TIMEOUT_ERROR 0x01113003U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_HOST_SWERR_PFIFO_LB_ERROR 0x01113004U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_HOST_SWERR_PBUS_SQUASH_ERROR 0x01113005U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_HOST_SWERR_PBUS_FECS_ERROR 0x01113006U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_HOST_SWERR_PBUS_TIMEOUT_ERROR 0x01113007U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_HOST_SWERR_PBDMA_TIMEOUT_ERROR 0x01113008U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_HOST_SWERR_PBDMA_EXTRA_ERROR 0x01113009U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_HOST_SWERR_PBDMA_GPFIFO_PB_ERROR 0x0111300aU
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_HOST_SWERR_PBDMA_METHOD_ERROR 0x0111300bU
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_HOST_SWERR_PBDMA_SIGNATURE_ERROR 0x0111300cU
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_HOST_SWERR_PBDMA_HCE_ERROR 0x0111300dU
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_HOST_SWERR_PBDMA_PREEMPT_ERROR 0x0111300eU
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_HOST_SWERR_PFIFO_CTXSW_TIMEOUT_ERROR 0x0111300fU
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_HOST_SWERR_PFIFO_FB_FLUSH_TIMEOUT_ERROR 0x01113010U
#define NVGUARD_SERVICE_IGPU_HOST_MAX_SWERR 17U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_IGPU_HOST_MAX_DIAG 0U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_IGPU_HOST_MAX_HWERR 0U
/* *************** END SERVICE ID for IGPU_HOST*************** */

/* *************** SERVICE ID for IGPU_SM*************** */
/*  IDs for SW Error Handler */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_SM_SWERR_L1_TAG_ECC_CORRECTED 0x01113400U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_SM_SWERR_L1_TAG_ECC_UNCORRECTED 0x01113401U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_SM_SWERR_CBU_ECC_UNCORRECTED 0x01113403U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_SM_SWERR_LRF_ECC_UNCORRECTED 0x01113405U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_SM_SWERR_L1_DATA_ECC_UNCORRECTED 0x01113407U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_SM_SWERR_ICACHE_L0_DATA_ECC_UNCORRECTED 0x01113409U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_SM_SWERR_ICACHE_L1_DATA_ECC_UNCORRECTED 0x0111340bU
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_SM_SWERR_ICACHE_L0_PREDECODE_ECC_UNCORRECTED 0x0111340dU
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_SM_SWERR_L1_TAG_MISS_FIFO_ECC_UNCORRECTED 0x0111340fU
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_SM_SWERR_L1_TAG_S2R_PIXPRF_ECC_UNCORRECTED 0x01113411U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_SM_SWERR_MACHINE_CHECK_ERROR 0x01113412U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_SM_SWERR_ICACHE_L1_PREDECODE_ECC_UNCORRECTED 0x01113414U
#define NVGUARD_SERVICE_IGPU_SM_MAX_SWERR 21U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_IGPU_SM_MAX_DIAG 0U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_IGPU_SM_MAX_HWERR 0U
/* *************** END SERVICE ID for IGPU_SM*************** */

/* *************** SERVICE ID for IGPU_FECS*************** */
/*  IDs for SW Error Handler */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_FECS_SWERR_FALCON_IMEM_ECC_CORRECTED 0x01113800U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_FECS_SWERR_FALCON_IMEM_ECC_UNCORRECTED 0x01113801U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_FECS_SWERR_FALCON_DMEM_ECC_UNCORRECTED 0x01113803U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_FECS_SWERR_CTXSW_WATCHDOG_TIMEOUT 0x01113804U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_FECS_SWERR_CTXSW_CRC_MISMATCH 0x01113805U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_FECS_SWERR_FAULT_DURING_CTXSW 0x01113806U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_FECS_SWERR_CTXSW_INIT_ERROR 0x01113807U
#define NVGUARD_SERVICE_IGPU_FECS_MAX_SWERR 8U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_IGPU_FECS_MAX_DIAG 0U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_IGPU_FECS_MAX_HWERR 0U
/* *************** END SERVICE ID for IGPU_FECS*************** */

/* *************** SERVICE ID for IGPU_GPCCS*************** */
/*  IDs for SW Error Handler */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_GPCCS_SWERR_FALCON_IMEM_ECC_CORRECTED 0x01113c00U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_GPCCS_SWERR_FALCON_IMEM_ECC_UNCORRECTED 0x01113c01U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_GPCCS_SWERR_FALCON_DMEM_ECC_UNCORRECTED 0x01113c03U
#define NVGUARD_SERVICE_IGPU_GPCCS_MAX_SWERR 4U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_IGPU_GPCCS_MAX_DIAG 0U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_IGPU_GPCCS_MAX_HWERR 0U
/* *************** END SERVICE ID for IGPU_GPCCS*************** */

/* *************** SERVICE ID for IGPU_MMU*************** */
/*  IDs for SW Error Handler */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_MMU_SWERR_L1TLB_SA_DATA_ECC_UNCORRECTED 0x01114001U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_MMU_SWERR_L1TLB_FA_DATA_ECC_UNCORRECTED 0x01114003U
#define NVGUARD_SERVICE_IGPU_MMU_MAX_SWERR 4U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_IGPU_MMU_MAX_DIAG 0U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_IGPU_MMU_MAX_HWERR 0U
/* *************** END SERVICE ID for IGPU_MMU*************** */

/* *************** SERVICE ID for IGPU_GCC*************** */
/*  IDs for SW Error Handler */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_GCC_SWERR_L15_ECC_UNCORRECTED 0x01114401U
#define NVGUARD_SERVICE_IGPU_GCC_MAX_SWERR 2U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_IGPU_GCC_MAX_DIAG 0U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_IGPU_GCC_MAX_HWERR 0U
/* *************** END SERVICE ID for IGPU_GCC*************** */

/* *************** SERVICE ID for IGPU_PMU*************** */
/*  IDs for SW Error Handler */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_PMU_SWERR_FALCON_IMEM_ECC_CORRECTED 0x01114800U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_PMU_SWERR_FALCON_IMEM_ECC_UNCORRECTED 0x01114801U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_PMU_SWERR_FALCON_DMEM_ECC_UNCORRECTED 0x01114803U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_PMU_SWERR_BAR0_ERROR_TIMEOUT 0x01114804U
#define NVGUARD_SERVICE_IGPU_PMU_MAX_SWERR 5U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_IGPU_PMU_MAX_DIAG 0U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_IGPU_PMU_MAX_HWERR 0U
/* *************** END SERVICE ID for IGPU_PMU*************** */

/* *************** SERVICE ID for IGPU_PGRAPH*************** */
/*  IDs for SW Error Handler */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_PGRAPH_SWERR_FE_EXCEPTION 0x01114c00U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_PGRAPH_SWERR_MEMFMT_EXCEPTION 0x01114c01U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_PGRAPH_SWERR_PD_EXCEPTION 0x01114c02U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_PGRAPH_SWERR_SCC_EXCEPTION 0x01114c03U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_PGRAPH_SWERR_DS_EXCEPTION 0x01114c04U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_PGRAPH_SWERR_SSYNC_EXCEPTION 0x01114c05U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_PGRAPH_SWERR_MME_EXCEPTION 0x01114c06U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_PGRAPH_SWERR_SKED_EXCEPTION 0x01114c07U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_PGRAPH_SWERR_BE_EXCEPTION 0x01114c08U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_PGRAPH_SWERR_MPC_EXCEPTION 0x01114c09U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_PGRAPH_SWERR_ILLEGAL_ERROR 0x01114c0aU
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_PGRAPH_SWERR_GPC_GFX_EXCEPTION 0x01114c0bU
#define NVGUARD_SERVICE_IGPU_PGRAPH_MAX_SWERR 12U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_IGPU_PGRAPH_MAX_DIAG 0U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_IGPU_PGRAPH_MAX_HWERR 0U
/* *************** END SERVICE ID for IGPU_PGRAPH*************** */

/* *************** SERVICE ID for IGPU_LTC*************** */
/*  IDs for SW Error Handler */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_LTC_SWERR_CACHE_DSTG_ECC_CORRECTED 0x01115000U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_LTC_SWERR_CACHE_DSTG_ECC_UNCORRECTED 0x01115001U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_LTC_SWERR_CACHE_TSTG_ECC_UNCORRECTED 0x01115003U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_LTC_SWERR_CACHE_DSTG_BE_ECC_UNCORRECTED 0x01115007U
#define NVGUARD_SERVICE_IGPU_LTC_MAX_SWERR 8U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_IGPU_LTC_MAX_DIAG 0U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_IGPU_LTC_MAX_HWERR 0U
/* *************** END SERVICE ID for IGPU_LTC*************** */

/* *************** SERVICE ID for IGPU_HUBMMU*************** */
/*  IDs for SW Error Handler */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_HUBMMU_SWERR_L2TLB_SA_DATA_ECC_UNCORRECTED 0x01115401U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_HUBMMU_SWERR_TLB_SA_DATA_ECC_UNCORRECTED 0x01115403U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_HUBMMU_SWERR_PTE_DATA_ECC_UNCORRECTED 0x01115405U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_HUBMMU_SWERR_PDE0_DATA_ECC_UNCORRECTED 0x01115407U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_HUBMMU_SWERR_PAGE_FAULT_ERROR 0x01115408U
#define NVGUARD_SERVICE_IGPU_HUBMMU_MAX_SWERR 9U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_IGPU_HUBMMU_MAX_DIAG 0U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_IGPU_HUBMMU_MAX_HWERR 0U
/* *************** END SERVICE ID for IGPU_HUBMMU*************** */

/* *************** SERVICE ID for IGPU_PRI*************** */
/*  IDs for SW Error Handler */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_PRI_SWERR_TIMEOUT_ERROR 0x01115800U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_PRI_SWERR_ACCESS_VIOLATION 0x01115801U
#define NVGUARD_SERVICE_IGPU_PRI_MAX_SWERR 2U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_IGPU_PRI_MAX_DIAG 0U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_IGPU_PRI_MAX_HWERR 0U
/* *************** END SERVICE ID for IGPU_PRI*************** */

/* *************** SERVICE ID for IGPU_CE*************** */
/*  IDs for SW Error Handler */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_CE_SWERR_LAUNCH_ERROR 0x01115c00U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_CE_SWERR_BLOCK_PIPE 0x01115c01U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_CE_SWERR_INVALID_CONFIG 0x01115c03U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_IGPU_CE_SWERR_METHOD_BUFFER_FAULT 0x01115c04U
#define NVGUARD_SERVICE_IGPU_CE_MAX_SWERR 5U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_IGPU_CE_MAX_DIAG 0U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_IGPU_CE_MAX_HWERR 0U
/* *************** END SERVICE ID for IGPU_CE*************** */

/* *************** SERVICE ID for HV*************** */
/*  IDs for SW Error Handler */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_HV_SWERR_GENERAL_FAULT 0x01116000U
#define NVGUARD_SERVICE_HV_MAX_SWERR 1U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_HV_MAX_DIAG 0U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_HV_MAX_HWERR 0U
/* *************** END SERVICE ID for HV*************** */

/* *************** SERVICE ID for PLATFORM*************** */
/*  IDs for SW Error Handler */
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_PLATFORM_SWERR_PMIC_THERMAL_ALARM 0x01116400U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_PLATFORM_SWERR_PMIC_FAILURE 0x01116401U
/** DESCRIPTION :  */
#define NVGUARD_SERVICE_PLATFORM_SWERR_TMON_FAILURE 0x01116402U
#define NVGUARD_SERVICE_PLATFORM_MAX_SWERR 3U
/* IDs for Diagnostics Test Services */
#define NVGUARD_SERVICE_PLATFORM_MAX_DIAG 0U
/* IDs for HW Error Handlers */
#define NVGUARD_SERVICE_PLATFORM_MAX_HWERR 0U
/* *************** END SERVICE ID for PLATFORM*************** */

#define NVGUARD_MAX_HSM_ERRORS        (512U)
#define NVGUARD_MAX_DIAGNOSTIC_TESTS  (109U)

/*
Global Maxima for Software = 64
Global Maxima Group for Software = DRIVEOSAPP
Global Maxima for Diagnostics = 64
Global Maxima Group for Diagnostics = DRIVEOSAPP
Global Maxima for Hardware = 112
Global Maxima Group for Hardware = TSA
*/
/** HW HSM SERVICES which are Disabled */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_26  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_27  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_36  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_37  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_38  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_39  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_41  */
/* NVGUARD_SERVICE_INVALID_HSMERR_GPU_INTR_1_UE  */
/* NVGUARD_SERVICE_INVALID_HSMERR_GPU_INTR_0_UE  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_102  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_103  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_104  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_105  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_106  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_107  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_108  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_109  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_166  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_167  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_173  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_174  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_175  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_176  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_177  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_181  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_182  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_188  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_189  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_191  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_192  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_193  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_194  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_196  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_198  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_245  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_246  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_247  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_248  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_249  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_250  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_251  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_258  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_259  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_260  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_261  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_292  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_293  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_294  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_295  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_298  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_299  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_300  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_301  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_302  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_303  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_304  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_305  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_306  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_307  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_308  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_309  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_310  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_311  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_312  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_313  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_314  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_315  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_316  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_317  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_318  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_319  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_339  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_349  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_402  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_403  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_405  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_408  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_409  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_410  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_411  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_412  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_413  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_414  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_415  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_477  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_478  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_479  */
/* NVGUARD_SERVICE_INVALID_HSMERR_RSVD_480  */

typedef uint32_t nv_guard_service_id_t;
#endif
